#!/usr/bin/env python

#Librarys
###########################################################################################
import gtk
import os

#Files
###########################################################################################
from Windows import Windows
from Communicate import Communicate
from About import About

#Classes
###########################################################################################
class Coffee:
	def __init__(self):
		self.About = About(self)
		self.Communicate = Communicate(self)
		self.Communicate.start()
		self.Windows = Windows(self)
		self.Windows.start()

	def quit(self, ignore1, ignore2):
		gtk.main_quit()

#Run
###########################################################################################
if __name__ == "__main__":
	os.chdir("/opt/bluetooth-coffeemaker/")
	Coffee()
